pub struct TestProject { /* private fields */ }Expand description
Implementations
Sourceimpl TestProject
impl TestProject
Sourcepub fn pnpm() -> Self
pub fn pnpm() -> Self
A minimal pnpm project. Runs pnpm install on build to resolve dependencies.
pub fn dependency(self, name: &str, version: &str) -> Self
pub fn dev_dependency(self, name: &str, version: &str) -> Self
Sourcepub fn member(
self,
path: &str,
build: impl FnOnce(TestMember) -> TestMember,
) -> Self
pub fn member( self, path: &str, build: impl FnOnce(TestMember) -> TestMember, ) -> Self
Add a workspace member at the given relative path. The closure receives
an empty [TestMember] to configure with its own dependencies.
pub fn source_file(self, name: &str, content: &str) -> Self
pub fn scute_config(self, yaml: &str) -> Self
Sourcepub fn nested(self, path: &str, child: TestProject) -> Self
pub fn nested(self, path: &str, child: TestProject) -> Self
Nest a child project at the given relative path inside this project.